@@ -190,7 +190,7 @@ class DbApiHook(BaseHook):
         return getattr(self, self.conn_name_attr)
 
     @cached_property
-    def placeholder(self):
+    def placeholder(self) -> str:
         placeholder = self.connection_extra.get("placeholder")
         if placeholder:
             if placeholder in SQL_PLACEHOLDERS:
@@ -235,9 +235,11 @@ class DbApiHook(BaseHook):
         """
         return {k.lower(): v for k, v in self.connection_extra.items()}
 
-    def get_conn(self):
+    def get_conn(self) -> Any:
         """Return a connection object."""
         db = self.connection
+        if self.connector is None:
+            raise RuntimeError(f"{type(self).__name__} didn't have `self.connector` set!")
         return self.connector.connect(host=db.host, port=db.port, username=db.login, schema=db.schema)
 
     def get_uri(self) -> str:
@@ -570,7 +572,7 @@ class DbApiHook(BaseHook):
         """
         return getattr(conn, "autocommit", False) and self.supports_autocommit
 
-    def get_cursor(self):
+    def get_cursor(self) -> Any:
         """Return a cursor."""
         return self.get_conn().cursor()
 
@@ -618,6 +620,7 @@ class DbApiHook(BaseHook):
         replace=False,
         *,
         executemany=False,
+        fast_executemany=False,
         autocommit=False,
         **kwargs,
     ):
@@ -636,6 +639,8 @@ class DbApiHook(BaseHook):
         :param executemany: If True, all rows are inserted at once in
             chunks defined by the commit_every parameter. This only works if all rows
             have same number of column names, but leads to better performance.
+        :param fast_executemany: If True, the `fast_executemany` parameter will be set on the
+            cursor used by `executemany` which leads to better performance, if supported by driver.
         :param autocommit: What to set the connection's autocommit setting to
             before executing the query.
         """
@@ -644,6 +649,15 @@ class DbApiHook(BaseHook):
             conn.commit()
             with closing(conn.cursor()) as cur:
                 if self.supports_executemany or executemany:
+                    if fast_executemany:
+                        with contextlib.suppress(AttributeError):
+                            # Try to set the fast_executemany attribute
+                            cur.fast_executemany = True
+                            self.log.info(
+                                "Fast_executemany is enabled for conn_id '%s'!",
+                                self.get_conn_id(),
+                            )
+
                     for chunked_rows in chunked(rows, commit_every):
                         values = list(
                             map(
